@@ -12,7 +12,7 @@ set -euo pipefail
 function usage() {
 	local n="$(basename "${0}")"
 	cat >&2 <<EOT
-Usage: ${n} {docs | pypi}
+Usage: ${n} {docs | lint | pypi}
        ${n} setver {version}
 EOT
 	exit 1
@@ -32,6 +32,19 @@ function _docs() {
 	popd >/dev/null
 }
 
+function _lint() {
+	local fn tmp=$(mktemp)
+	# shellcheck disable=2064
+	trap "rm $tmp" EXIT
+	for fn in contrib/*.json; do
+		jsonlint --strict --format --sort preserve "$fn" |
+			sed -e 's/" :/":/g' -e 's/[[:space:]]\+$//' >"$tmp"
+		catto "$fn" "$tmp"
+	done
+	flake8 . --select=E9,F63,F7,F82 --show-source
+	flake8 . --exit-zero
+}
+
 function _pypi() {
 	twine upload dist/*
 }
@@ -48,7 +61,7 @@ function _setver() {
 declare -r verb="${1}"
 shift
 case "${verb}" in
-docs | setver)
+docs | lint | setver)
 	_"${verb}" "$@"
 	;;
 pypi)
