@@ -20,7 +20,7 @@ along with automx2. If not, see <https://www.gnu.org/licenses/>.
 import logging
 
 IDENTIFIER = "automx2"  # Do not change this!
-__version__ = "2026.0"
+__version__ = "2026.1"
 
 PLACEHOLDER_ADDRESS = r"%EMAILADDRESS%"
 PLACEHOLDER_DOMAIN = r"%EMAILDOMAIN%"
@@ -93,6 +93,12 @@ class LdapNoMatch(NotFoundException):
     pass
 
 
+class SeedingAborted(AutomxException):
+    """Database seeding failed."""
+
+    pass
+
+
 log = logging.getLogger(__name__)
 _handler = logging.StreamHandler()
 _handler.setFormatter(logging.Formatter())
