@@ -20,15 +20,16 @@ along with automx2. If not, see <https://www.gnu.org/licenses/>.
 import os
 import unittest
 
-from automx2 import InvalidEMailAddressError
 from automx2 import PLACEHOLDER_ADDRESS
 from automx2 import PLACEHOLDER_DOMAIN
 from automx2 import PLACEHOLDER_LOCALPART
-from automx2.util import expand_placeholders
+from automx2 import InvalidEMailAddressError
 from automx2.util import dictget_optional
+from automx2.util import expand_placeholders
 from automx2.util import from_environ
 from automx2.util import parse_email_address
 from automx2.util import socket_type_needs_ssl
+from automx2.util import truthy
 from automx2.util import unique
 
 
@@ -93,6 +94,18 @@ class UtilTests(unittest.TestCase):
         self.assertFalse(socket_type_needs_ssl("STARTTLS"))
         self.assertFalse(socket_type_needs_ssl("INVALID"))
 
+    def test_truthy_false(self):
+        self.assertFalse(truthy("no"))
+        self.assertFalse(truthy(0))
+        self.assertFalse(truthy(0.1))
+        self.assertFalse(truthy(False))
+        self.assertFalse(truthy(None))
+
+    def test_truthy_true(self):
+        self.assertTrue(truthy("yes"))
+        self.assertTrue(truthy(1))
+        self.assertTrue(truthy(True))
+
 
 if __name__ == "__main__":
     unittest.main()
